from django.core.management.base import BaseCommand

from allianceauth.authentication.models import State

from alumni import app_settings


class Command(BaseCommand):
    help = 'Setup/Reset/Fix the Alumni State for the Alumni Module'

    def handle(self, *args, **options):
        self.stdout.write("Creating/Reseting/Fixing the Alumni State for the Alumni Module")
        alumni_name = app_settings.ALUMNI_STATE_NAME
        priority = 1

        created = State.objects.update_or_create(name=alumni_name,
                                                 defaults={
                                                     "priority": priority,
                                                 })
        if created:
            self.stdout.write("Success! Created Alumni State")
        else:
            self.stdout.write("Success! Updated Alumni State")



from django.core.exceptions import ValidationError
from django.db import models

from allianceauth.eveonline.models import (
    EveAllianceInfo, EveCharacter, EveCorporationInfo,
)


class AlumniSetup(models.Model):
    alumni_corporations = models.ManyToManyField(EveCorporationInfo,
                                                 blank=True,
                                                 help_text="Characters with these Corps in their History will be given Alumni Status")
    alumni_alliances = models.ManyToManyField(EveAllianceInfo,
                                              blank=True,
                                              help_text="Characters with these Alliances in their History will be given Alumni Status")

    def save(self, *args, **kwargs):
        if not self.pk and AlumniSetup.objects.exists():
            # Force a single object
            raise ValidationError('There is can be only one \
                                   AlumniCorp instance')
        self.pk = self.id = 1  # If this happens to be deleted and recreated, force it to be 1
        return super().save(*args, **kwargs)

    class Meta:
        verbose_name_plural = "Alumni Config"


class CorporationAllianceHistory(models.Model):
    class Meta:
        constraints = [
            models.UniqueConstraint(fields=['corporation_id', 'record_id'], name="CorporationAllianceRecord"),
        ]
    corporation_id = models.PositiveIntegerField(db_index=True)
    alliance_id = models.PositiveIntegerField(blank=True, null=True, db_index=True)
    is_deleted = models.BooleanField(default=False,
                                     help_text='True if the corporation has been deleted')
    record_id = models.IntegerField(
        help_text='An incrementing ID that can be used to canonically establish order of records in cases where dates may be ambiguous')
    start_date = models.DateTimeField()


class CharacterCorporationHistory(models.Model):
    class Meta:
        constraints = [
            models.UniqueConstraint(fields=['character', 'record_id'], name="CharacterCorporationRecord"),
        ]
    character = models.ForeignKey(EveCharacter,
                                  on_delete=models.CASCADE)
    corporation_id = models.PositiveIntegerField()
    is_deleted = models.BooleanField(default=False,
                                     help_text='True if the corporation has been deleted')
    record_id = models.IntegerField(
        help_text='An incrementing ID that can be used to canonically establish order of records in cases where dates may be ambiguous')
    start_date = models.DateTimeField()



# Generated by Django 3.2.10 on 2021-12-30 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('alumni', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='corporationalliancehistory',
            name='alliance_id',
            field=models.PositiveIntegerField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='corporationalliancehistory',
            name='corporation_id',
            field=models.PositiveIntegerField(db_index=True),
        ),
    ]



from django.apps import AppConfig

from . import __version__


class AlumniConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = "alumni"
    label = "alumni"
    verbose_name = f"alumni v{__version__}"



import os

from setuptools import find_packages, setup

from alumni import __version__

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='aa-alumni',
    version=__version__,
    packages=find_packages(),
    include_package_data=True,
    license="MIT",
    description='Alliance Auth Plugin',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://gitlab.com/tactical-supremacy/aa-alumni',
    author='Joel Falknau',
    author_email='joel.falknau@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    python_requires='~=3.7',
    install_requires=[
        "allianceauth>=2.9.0",
    ],

)



# Generated by Django 3.2.10 on 2021-12-29 11:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('eveonline', '0015_factions'),
    ]

    operations = [
        migrations.CreateModel(
            name='AlumniSetup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'verbose_name_plural': 'Alumni Config',
            },
        ),
        migrations.CreateModel(
            name='CharacterCorporationHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corporation_id', models.PositiveIntegerField()),
                ('is_deleted', models.BooleanField(default=False, help_text='True if the corporation has been deleted')),
                ('record_id', models.IntegerField(help_text='An incrementing ID that can be used to canonically establish order of records in cases where dates may be ambiguous')),
                ('start_date', models.DateTimeField()),
            ],
        ),
        migrations.CreateModel(
            name='CorporationAllianceHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('corporation_id', models.PositiveIntegerField()),
                ('alliance_id', models.PositiveIntegerField(blank=True, null=True)),
                ('is_deleted', models.BooleanField(default=False, help_text='True if the corporation has been deleted')),
                ('record_id', models.IntegerField(help_text='An incrementing ID that can be used to canonically establish order of records in cases where dates may be ambiguous')),
                ('start_date', models.DateTimeField()),
            ],
        ),
        migrations.AddConstraint(
            model_name='corporationalliancehistory',
            constraint=models.UniqueConstraint(fields=('corporation_id', 'record_id'), name='CorporationAllianceRecord'),
        ),
        migrations.AddField(
            model_name='charactercorporationhistory',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveonline.evecharacter'),
        ),
        migrations.AddField(
            model_name='alumnisetup',
            name='alumni_alliances',
            field=models.ManyToManyField(blank=True, help_text='Characters with these Alliances in their History will be given Alumni Status', to='eveonline.EveAllianceInfo'),
        ),
        migrations.AddField(
            model_name='alumnisetup',
            name='alumni_corporations',
            field=models.ManyToManyField(blank=True, help_text='Characters with these Corps in their History will be given Alumni Status', to='eveonline.EveCorporationInfo'),
        ),
        migrations.AddConstraint(
            model_name='charactercorporationhistory',
            constraint=models.UniqueConstraint(fields=('character', 'record_id'), name='CharacterCorporationRecord'),
        ),
    ]
